package com.huimv.location;

import com.alibaba.fastjson.JSONArray;
import com.huimv.location.service.BeaconService;
import com.huimv.location.utils.HttpClient;
import com.huimv.location.utils.StringUtils;
import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;

import java.io.UnsupportedEncodingException;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

@SpringBootTest
class LocationApplicationTests {
    @Autowired
    private HttpClient httpClient;
    @Autowired
    private com.huimv.location.utils.StringUtils stringUtils;
    @Autowired
    private BeaconService beaconService;
    private final String host_url = "http://192.168.1.17:44444";

    /**
     * @Method      : testHttpClient
     * @Description : 获取单个信标数据
     * @Params      : []
     * @Return      : void
     *
     * @Author      : ZhuoNing
     * @Date        : 2021/9/15
     * @Time        : 18:39
     */
    @Test
    void testGetOneBeaconInfo() {
        String url = host_url + "/beacons/32b00ae08dfc";
        String outData = httpClient.doGet(url);
        System.out.println("输出单个信标数据>>"+outData);
    }

    /**
     * @Method      : testGetOneLocatorInfo
     * @Description : 获取单个基站数据
     * @Params      : []
     * @Return      : void
     *
     * @Author      : ZhuoNing
     * @Date        : 2021/9/15
     * @Time        : 18:44
     */
    @Test
    void testGetOneLocatorInfo(){
        String url = host_url + "/locators/3c:fa:d3:b0:4a:7c";
        String outData = httpClient.doGet(url);
        System.out.println("输出单个基站数据>>"+outData);
    }

    /**
     * @Method      :
     * @Description : 读取所有信标
     * @Params      :
     * @Return      :
     *
     * @Author      : ZhuoNing
     * @Date        : 2021/9/17
     * @Time        : 17:47
     */
    @Test
    public void testGetAllBeacon() throws UnsupportedEncodingException {
        String url = host_url + "/beacons";
        String outData = httpClient.doGet(url);
        System.out.println("输出所有信标数据>>"+outData);
        System.out.println("bytes:"+stringUtils.getBytes(outData));
        System.out.println("KB:"+stringUtils.getKBytes(outData));
        System.out.println("MB:"+stringUtils.getMBytes(outData));
    }

    /*
     * @Method      : testGetAllLocators
     * @Description : 读取
     * @Params      : []
     * @Return      : void
     * 
     * @Author      : ZhuoNing
     * @Date        : 2021/9/17       
     * @Time        : 17:59
     */
    @Test
    public void testGetAllLocators(){
        String url = host_url + "/locators";
        String outData = httpClient.doGet(url);
        System.out.println("输出所有基站数据>>"+outData);
    }

    private final String ENCODE = "UTF-8";

    @Test
    public void testGetBytes() throws UnsupportedEncodingException {
        String url = host_url + "/locators";
        String outData = httpClient.doGet(url);
        System.out.println("输出所有基站数据>>"+outData);
        System.out.println("bytes:"+stringUtils.getBytes(outData));
        System.out.println("KB:"+stringUtils.getKBytes(outData));
        System.out.println("MB:"+stringUtils.getMBytes(outData));
    }

    @Test
    public void testGetAllBeacons() throws UnsupportedEncodingException {
//        JSONArray beaconsJa = beaconService.getRemoteBeacons();
//        System.out.println("beaconsJa.size>>"+beaconsJa.size());
        beaconService.saveBeacon();
    }

    @Test
    public void testReg(){
//        String text = "{32b00ae08df8:{'userDataTs':{'0':1631934639769,'8':1631934639869},'userData':{'0':{'channelBit':1,'channel':2402,'frequency':10,'recv':false,'power':{'type':'Nordic','value':0},'sos':false,'battery':100},'8':{'gSensors':[3,248,64]}},'x':6.621938228607178,'y':3.649260997772217,'z':0.75,'rssi':-69.68558502197266,'mapId':'Wyl19hDwLo','zoneId':'others','updatedAt':1631929084213,'calculatedAt':1631929084213,'lastGateway':'3cfad3b040b3','gps':null},";
//String text = "{\"32b00ae08df8\":{\"userDataTs\":{\"0\":1631934639769,\"8\":1631934639869},\"userData\":{\"0\":{\"channelBit\":1,\"channel\":2402,\"frequency\":10,\"recv\":false,\"power\":{\"type\":\"Nordic\",\"value\":0},\"sos\":false,\"battery\":100},\"8\":{\"gSensors\":[3,248,64]}},\"x\":6.621938228607178,\"y\":3.649260997772217,\"z\":0.75,\"rssi\":-69.68558502197266,\"mapId\":\"Wyl19hDwLo\",\"zoneId\":\"others\",\"updatedAt\":1631929084213,\"calculatedAt\":1631929084213,\"lastGateway\":\"3cfad3b040b3\",\"gps\":null},";
//String text = "gSensors:[4,254,190]}},x:4.533107757568359,y:3.0880229473114014,z:0.75,rssi:-56.86811065673828,mapId:Wyl19hDwLo,zoneId:others,updatedAt:1631935837162,calculatedAt:1631935837163,lastGateway:3cfad3b04a7c,gps:null},32b00ae08dfe";
        String text = "},32b00ae08dfe";
//        String[] textArray = text.split("(^\\d+([\\d+|a-z])+){12}");
//        String[] textArray = text.split("(^\\d+)");
//        String[] textArray = text.split("(^\\d{2}(\\d|[a-z])){10}");
//        System.out.println("textArray.length>>"+textArray.length+",textArray[0]="+textArray[0]);
//
//        String[] textArray2 = text.split("32b00ae08df8:");
//        System.out.println("textArray2.length>>"+textArray2.length+",textArray2[0]="+textArray2[0]);

        JSONArray beaconMacJa = new JSONArray();
        String[] textArray3 = text.split("\":\\{");
//        System.out.println("textArray3.length>>"+textArray3.length+",textArray3[0]="+textArray3[0]);
        for(int a=0;a<textArray3.length;a++){
//            System.out.println("length()>>"+textArray3[a].trim().length()+","+textArray3[a].trim().replace("{",""));
//            System.out.println("textArray3.length>>"+textArray3.length+",textArray3>>"+textArray3);
//            int start = textArray3.length - 12;
            String sectionData = textArray3[a];
            if(sectionData.length()>=12) {
//                Pattern pattern = Pattern.compile("^(?!^$)([0-9]|[a-z]{12})$");
                //System.out.println(pattern.pattern());
                Pattern pattern = Pattern.compile(".*([0-9]|[a-z]{12})*");
                String text3 = sectionData.trim().replace("{","").replace("\"","");
                System.out.println("text3>>"+text3);
                Matcher isNum = pattern.matcher(text3);
                System.out.println("isNum.matches()>>"+isNum.matches());
                if( isNum.matches() )
                {
                    String mac = textArray3[a].substring(sectionData.length() - 12, sectionData.length());
                    System.out.println("mac:" + mac);
                    if (mac.length() == 12) {
                        beaconMacJa.add(mac);
//                String t = textArray3[a].replace("{","").replace("\"","");
//                System.out.println("t:"+t);
                    }
                }
//                System.out.println("sectionData.length>>" + sectionData.length() + " sectionData>>" + sectionData);
//                int start = sectionData.length() - 12;
//                int end = sectionData.length();
////                System.out.println("start>>" + start + ",end>>" + end);
//                String mac = textArray3[a].substring(start, end);
//                System.out.println("mac:" + mac);
//                if (mac.length() == 12) {
//                    beaconMacJa.add(mac);
////                String t = textArray3[a].replace("{","").replace("\"","");
////                System.out.println("t:"+t);
//                }
            }
        }
        System.out.println("beaconMacJa>>"+beaconMacJa);
    }

    @Test
    public void testReg2(){
        String text = "32b00ae08dfc";
        Pattern pattern = Pattern.compile("[a-z0-9]+");
        Matcher isNum = pattern.matcher(text);
        System.out.println("isNum.matches()>>"+isNum.matches());
    }

    @Test
    public void testTotal() throws UnsupportedEncodingException {
        String text = "{\"32b00ae08dfe\":{\"userDataTs\":{\"0\":1631965870429,\"8\":1631965870229},\"userData\":{\"0\":{\"channelBit\":1,\"channel\":2402,\"frequency\":5,\"recv\":false,\"power\":{\"type\":\"Nordic\",\"value\":0},\"sos\":false,\"battery\":100},\"8\":{\"gSensors\":[3,253,63]}},\"x\":4.753356456756592,\"y\":5.028262138366699,\"z\":0.75,\"rssi\":-54.93968200683594,\"mapId\":\"Wyl19hDwLo\",\"zoneId\":\"others\",\"updatedAt\":1631965870436,\"calculatedAt\":1631965870437,\"lastGateway\":\"3cfad3b040b3\",\"gps\":null},\"32b00ae08df7\":{\"userDataTs\":{\"0\":1631965870516,\"8\":1631965870314},\"userData\":{\"0\":{\"channelBit\":1,\"channel\":2402,\"frequency\":5,\"recv\":false,\"power\":{\"type\":\"Nordic\",\"value\":0},\"sos\":false,\"battery\":100},\"8\":{\"gSensors\":[3,255,65]}},\"x\":4.66012716293335,\"y\":5.065680027008057,\"z\":0.75,\"rssi\":-56.48079299926758,\"mapId\":\"Wyl19hDwLo\",\"zoneId\":\"others\",\"updatedAt\":1631965870532,\"calculatedAt\":1631965870532,\"lastGateway\":\"3cfad3b040b3\",\"gps\":null},\"32b00ae08e04\":{\"userDataTs\":{\"0\":1631965870197,\"8\":1631965870398},\"userData\":{\"0\":{\"channelBit\":1,\"channel\":2402,\"frequency\":5,\"recv\":false,\"power\":{\"type\":\"Nordic\",\"value\":0},\"sos\":false,\"battery\":100},\"8\":{\"gSensors\":[1,0,193]}},\"x\":4.234622955322266,\"y\":5.084767818450928,\"z\":0.75,\"rssi\":-56.58543395996094,\"mapId\":\"Wyl19hDwLo\",\"zoneId\":\"others\",\"updatedAt\":1631965870406,\"calculatedAt\":1631965870406,\"lastGateway\":\"3cfad3b04a7c\",\"gps\":null},\"84c2e4d234b6\":{\"userDataTs\":{\"0\":1631965830071},\"userData\":{\"0\":{\"channelBit\":1,\"channel\":2402,\"frequency\":6,\"recv\":false,\"power\":{\"type\":\"Nordic\",\"value\":0},\"sos\":false,\"battery\":90}},\"x\":3.1905453205108643,\"y\":5.413759231567383,\"z\":0.75,\"rssi\":-57.63712692260742,\"mapId\":\"Wyl19hDwLo\",\"zoneId\":\"others\",\"updatedAt\":1631965830073,\"calculatedAt\":1631965830074,\"lastGateway\":\"3cfad3b04a7c\",\"gps\":null}}";
        System.out.println("字节长度:"+stringUtils.getTextBytes(text,"UTF-8"));
    }


    
}
